from p2.store.client import Client
from p2.logging import HttpLogger

class BaseRunner:
    """A common base class to run experiments/templates."""

    def __init__(self, p2_store_url, filename, exp_id, campaign_id:dict=None):

        if not (p2_store_url and filename and exp_id):
            raise Exception("Not all parameters passed")

        self.filename = filename
        self.exp_id = exp_id
        self.campaign_id = campaign_id
        self.p2_store_url = p2_store_url
        self.client = Client(p2_store_url)
        log_obj = HttpLogger(
            silent=False,
            p2_store_url=p2_store_url,
            name=exp_id
        )
        self.log = log_obj.getLogger()

        self.log.info(f"Session: {exp_id}, Filename: {filename}")

        sessions = self.client.get_sessions(exp_id=self.exp_id)
        if ((sessions is None) or (len(sessions) == 0)):
            self.log.error("No session found")
            raise Exception("No session found")
        self.session = sessions[0]
        if self.session['status'] != 'scheduled':
            self.log.error("Session not in scheduled status, aborting...")
            raise Exception("Session not in scheduled status, aborting...")


    def run(self):
        """ Implemented by single driver """
        pass
